==> navigine_sdk-1.2.1%2B3.tar.gz: lib/controllers/navigation.dart <==
part of navigine_sdk;

class NavigationThread {
  StreamController<DeviceInfo>? controller;

  static Future<NavigationThread> startNavigation({
    NavigationMode mode = NavigationMode.MODE_NORMAL,
  }) async {
    await _channel.invokeMethod("startNavigation", {
      "mode": _getModeCode(mode),
    });
    return NavigationThread();
  }

  stopNavigation() async {
    await _channel.invokeMethod("stopNavigation");
  }

  Future<void> addTarget(LocationPoint point) async {
    await _channel.invokeMethod(
      "addTarget",
      {"locationPoint": point.toMap()},
    );
  }

  Future<void> cancelTarget() async {
    await _channel.invokeMethod("cancelTarget");
  }

  Future<RoutePath> makeRoute(
    LocationPoint point1,
    LocationPoint point2,
  ) async {
    return RoutePath.fromMap(
      await _channel.invokeMethod(
        "makeRoute",
        {
          "locationPoint1": point1.toMap(),
          "locationPoint2": point2.toMap(),
        },
      ),
    );
  }

  Stream<DeviceInfo> getDeviceInfoListener() {
    controller = StreamController<DeviceInfo>();
    _channel.setMethodCallHandler((call) async {
      switch (call.method) {
        case "deviceInfo#onUpdate":
          controller?.add(DeviceInfo.fromMap(call.arguments));
          break;
        default:
      }
    });
    controller!.onCancel = () async {
      await _channel.invokeMethod("stopNavigation");
      controller!.close();
      controller = null;
    };
    return controller!.stream;
  }

  Future<DeviceInfo> getDeviceInfo() async {
    return DeviceInfo.fromMap(await _channel.invokeMethod("getDeviceInfo"));
  }

  static _getModeCode(NavigationMode mode) {
    switch (mode) {
      case NavigationMode.MODE_IDLE:
        return 1;
      case NavigationMode.MODE_SCAN:
        return 2;
      case NavigationMode.MODE_NORMAL:
        return 3;
      case NavigationMode.MODE_ECONOMIC:
        return 4;
      default:
    }
  }
}

enum NavigationMode {
  MODE_IDLE,
  MODE_SCAN,
  MODE_NORMAL,
  MODE_ECONOMIC,
}

==> navigine_sdk-1.2.4%2B3.tar.gz: lib/controllers/navigation.dart <==
part of navigine_sdk;

class NavigationThread {
  NavigationThread._();

  StreamController<DeviceInfo>? _deviceInfoController;

  stopNavigation() async {
    await _channel.invokeMethod("stopNavigation");
  }

  Future<void> addTarget(LocationPoint point) async {
    await _channel.invokeMethod(
      "addTarget",
      {"locationPoint": point.toMap()},
    );
  }

  Future<void> cancelTarget() async {
    await _channel.invokeMethod("cancelTarget");
  }

  Future<RoutePath> makeRoute(
    LocationPoint point1,
    LocationPoint point2,
  ) async {
    return RoutePath.fromMap(
      await _channel.invokeMethod(
        "makeRoute",
        {
          "locationPoint1": point1.toMap(),
          "locationPoint2": point2.toMap(),
        },
      ),
    );
  }

  Stream<DeviceInfo> getDeviceInfoListener() {
    _deviceInfoController = StreamController<DeviceInfo>();
    _deviceInfoController!.onCancel = () async {
      await _channel.invokeMethod("stopNavigation");
      _deviceInfoController!.close();
      _deviceInfoController = null;
    };
    return _deviceInfoController!.stream;
  }

  Future<DeviceInfo> getDeviceInfo() async {
    return DeviceInfo.fromMap(await _channel.invokeMethod("getDeviceInfo"));
  }

  _handleNativeCall(MethodCall call) async {
    switch (call.method) {
      case "deviceInfo#onUpdate":
        _deviceInfoController?.add(DeviceInfo.fromMap(call.arguments));
        break;
      default:
    }
  }
}

enum NavigationMode {
  MODE_IDLE,
  MODE_SCAN,
  MODE_NORMAL,
  MODE_ECONOMIC,
}
